import {
  initVendorConsentsLoader,
  addVendorLoadedEventListener,
  loadComscore
} from '@adv-ui/vendor-by-consents-loader'
import getHotjarConfig from './hotjar/config'
import getOptimizelyConfig from './optimizely/config'

const COMSCORE_CLIENT_ID = '13013988'

const getPortal = () => {
  const match = window.location.href.match(/infojobs(\w*)\.(\w*)/)
  if (match) {
    const [, , portal] = match
    return portal === 'it' ? 'it' : 'es'
  }
  return 'es'
}

const loader = () => {
  const portal = getPortal()
  const path = window.location.pathname
  const {
    config: hotjarConfig,
    initScript: initHotjarScript,
    isEnabled: hotjarEnabled
  } = getHotjarConfig({
    portal,
    path
  })
  const {
    config: optimizelyConfig,
    isEnabled: optimizelyEnabled
  } = getOptimizelyConfig({portal, path})

  hotjarEnabled && initHotjarScript()

  loadComscore({comscoreClientId: COMSCORE_CLIENT_ID})

  initVendorConsentsLoader({
    vendors: {
      ...(hotjarEnabled && {hotjar: hotjarConfig}),
      ...(optimizelyEnabled && {optimizely: optimizelyConfig})
    }
  })

  addVendorLoadedEventListener(({vendor}) => {
    vendor === 'hotjar' && console.log('hotjar has been loaded')
    vendor === 'optimizely' && console.log('optimizely has been loaded')
  })
}

export default loader
