import {expect} from 'chai'
import getHotjarConfig from '../../../src/vendors/hotjar/config'

describe('getHotjarConfig', () => {
  it('should return the config if hotjar is enabled', () => {
    const expectedHotjarConfig = {
      script: '//static.hotjar.com/c/hotjar-223746.js?sv=5',
      consents: {
        purposes: [8, 9, 10],
        specialFeatureOptions: []
      }
    }

    const {
      config: hotjarConfig,
      initScript: initHotjarScript,
      isEnabled
    } = getHotjarConfig({portal: 'es', path: '/external-offer'})

    expect(hotjarConfig).to.be.deep.equal(expectedHotjarConfig)
    expect(isEnabled).to.be.true
    expect(initHotjarScript).to.not.be.be.undefined
  })

  it('should return an empty config object if hotjar is not enabled', () => {
    const expectedHotjarConfig = {}

    const {
      config: hotjarConfig,
      initScript: initHotjarScript,
      isEnabled
    } = getHotjarConfig({portal: 'es', path: '/random-path-not-included'})

    expect(hotjarConfig).to.be.deep.equal(expectedHotjarConfig)
    expect(isEnabled).to.be.false
    expect(initHotjarScript).to.not.be.be.undefined
  })
})
