import {expect} from 'chai'
import getOptimizelyConfig from '../../../src/vendors/optimizely/config'

describe('getOptimizelyConfig', () => {
  it('should return the config if optimizely is enabled', () => {
    const expectedOptimizelyConfig = {
      script: '//cdn.optimizely.com/js/5239650027.js',
      consents: {
        purposes: [10],
        specialFeatureOptions: []
      }
    }

    const {config: optimizelyConfig, isEnabled} = getOptimizelyConfig({
      portal: 'es',
      path: '/employer/menu/my-menu.xhtml'
    })
    expect(optimizelyConfig).to.be.deep.equal(expectedOptimizelyConfig)
    expect(isEnabled).to.be.true
  })

  it('should return an empty object if optimizely is not enabled', () => {
    const expectedOptimizelyConfig = {}

    const {config: optimizelyConfig, isEnabled} = getOptimizelyConfig({
      portal: 'es',
      path: '/random-path-not-included'
    })

    expect(optimizelyConfig).to.be.deep.equal(expectedOptimizelyConfig)
    expect(isEnabled).to.be.false
  })
})
